// mxgpio.cpp : Defines the exported functions for the DLL application.
//

/*  Copyright (C) MOXA Inc. All rights reserved.

    This software is distributed under the terms of the
    MOXA License.  See the file COPYING-MOXA for details.
*/
/*
    mxgpio.h

	Header files for GPIO functions

    2009-10-26	new release
	2013-09-28	modified for TC-DK10/20

*/
#include "stdafx.h"
#include "mxgpio.h"
#include <windows.h>
#include <stdio.h>
#include <winioctl.h>
#include "mxavalon.h"
#include "mxgpio.h"
#include "mxmdio.h"
#include "utils.h"

#ifdef __cplusplus    // If used by C++ code, 
extern "C" {          // we need to export the C interface
#endif

#define CMD_CODE_GET_MDIO_STATUS 0x1F //00011111

typedef struct _PRP_VALUE
{
    BYTE cardIndex; //Module Card Index 

	unsigned int rxGoodOctetsI; //RX_GOOD_OCTETS
	unsigned int rxGoodOctetsA;
	unsigned int rxGoodOctetsB;

	unsigned int rxBadOctetsI; //RX_BAD_OCTETS
	unsigned int rxBadOctetsA;
	unsigned int rxBadOctetsB;

	unsigned int rxUnicastI; //RX_UNITCAST
	unsigned int rxUnicastA;
	unsigned int rxUnicastB;

	unsigned int rxBroadcastI; //RX_BROADCAST
	unsigned int rxBroadcastA;
	unsigned int rxBroadcastB;

	unsigned int rxMulticastI; //RX_MULTICAST
	unsigned int rxMulticastA;
	unsigned int rxMulticastB;

	unsigned int rxUndersizeI; //RX_UNDERSIZE
	unsigned int rxUndersizeA;
	unsigned int rxUndersizeB;

	unsigned int rxFragementsI; //RX_FRAGEMENTS
	unsigned int rxFragementsA;
	unsigned int rxFragementsB;

	unsigned int rxOversizeI; //RX_OVERSIZE
	unsigned int rxOversizeA;
	unsigned int rxOversizeB;

	unsigned int rxJabberI; //RX_JABBER
	unsigned int rxJabberA;
	unsigned int rxJabberB;

	unsigned int rxErrI; //RX_ERR
	unsigned int rxErrA;
	unsigned int rxErrB;

	unsigned int rxCrcI; //RX_CRC
	unsigned int rxCrcA;
	unsigned int rxCrcB;

	unsigned int rx64I; //RX64
	unsigned int rx64A;
	unsigned int rx64B;

	unsigned int rx65_127I; //RX_65_127
	unsigned int rx65_127A;
	unsigned int rx65_127B;

	unsigned int rx128_255I; //RX_128_255
	unsigned int rx128_255A;
	unsigned int rx128_255B;

	unsigned int rx256_511I; //RX_256_511
	unsigned int rx256_511A;
	unsigned int rx256_511B;

	unsigned int rx512_1023I; //RX_512_1023
	unsigned int rx512_1023A;
	unsigned int rx512_1023B;

	unsigned int rx1024_1536I; //RX_1024_1536
	unsigned int rx1024_1536A;
	unsigned int rx1024_1536B;

	unsigned int rxHsrPrpI; //RX_HSRRP
	unsigned int rxHsrPrpA;
	unsigned int rxHsrPrpB;

	unsigned int rxWronglanI; //RX_WRONGLAN
	unsigned int rxWronglanA;
	unsigned int rxWronglanB;

	unsigned int rxDuplicateI; //RX_DUPLICATE
	unsigned int rxDuplicateA;
	unsigned int rxDuplicateB;

	unsigned int txOctetsI; //TX_OCTETS
	unsigned int txOctetsA;
	unsigned int txOctetsB;

	unsigned int txUnicastI; //TX_UNICAST
	unsigned int txUnicastA;
	unsigned int txUnicastB;

	unsigned int txMulticastI; //TX_MULTICAST
	unsigned int txMulticastA;
	unsigned int txMulticastB;

	unsigned int txBroadcastI; //TX_BROADCAST
	unsigned int txBroadcastA;
	unsigned int txBroadcastB;

	unsigned int txHsrPrpI; //TX_HSRPRP
	unsigned int txHsrPrpA;
	unsigned int txHsrPrpB;

	unsigned int priqDropI; //PRIQ_DROP
	unsigned int priqDropA;
	unsigned int priqDropB;

	unsigned int earlyDropI; //EARLY_DROP
	unsigned int earlyDropA;
	unsigned int earlyDropB;

    BYTE linkSpeedI; //Link Speed
    BYTE linkSpeedA;
    BYTE linkSpeedB;

    BYTE linkStatusI; //Link Status
    BYTE linkStatusA;
    BYTE linkStatusB;

    BYTE currMode; //1:Prp Mode, 2:HsrMode

}PRP_VALUE, *PPRP_VALUE;

/*
*
* Used to check if module card exists
*
*/
int GetMdioBusStatus(UINT8 slaveAddr); //1:Module Exists, 0:Module does not exist

int SetPrpMode(UINT8 slaveAddr);

int SetHsrMode(UINT8 slaveAddr);

/*
*
* Main function to set PRP mode
*
*/
int GetRxCounter(UINT8 slaveAddr, UINT8 portSel, unsigned short counterOffset, unsigned short *rxCounter);
int GetTxCounter(UINT8 slaveAddr, UINT8 portSel, unsigned short counterOffset, unsigned short *txCounter);

int ConfigureCntCtrl(UINT8 slaveAddr, UINT8 portSel);

int ReadRxCounters(UINT8 slaveAddr, UINT8 portSel, unsigned short counterOffset, UINT8 *counterValue);
int ReadTxCounters(UINT8 slaveAddr, UINT8 portSel, unsigned short counterOffset, UINT8 *counterValue);

int ConfigureGpioMode(UINT8 slaveAddr, int ledIndex);
int SetLedValue(UINT8 slaveAddr, int ledIndex);
int VerifyLedValue(UINT8 slaveAddr);

int SetLinkSpeedMode(UINT8 slaveAddr);

int GetLinkStatus(UINT8 slaveAddr, UINT8 phyAddr);


#ifdef __cplusplus    // If used by C++ code, 
}
#endif