/*  Copyright (C) MOXA Inc. All rights reserved.

    This software is distributed under the terms of the
    MOXA License.  See the file COPYING-MOXA for details.
*/

#ifndef _MXSMBUS_H_ 
#define _MXSMBUS_H_

#define SMBUS_SLAVE_ADDRESS 0x58; //0xB0

typedef unsigned char UINT8;

#define GSENSOR_NUMBER	2


typedef struct _GSENSORDATA
{
	UINT16 x_axis;	//x-axis value
	UINT16 y_axis;	//y-axis value
	UINT16 z_axis;	//z-axis value
	
}GSENSORDATA, *PGSENSORDATA;

typedef struct _SMBUSSETTING {
	UINT8	device_id;			//g-sensor status(0 : normal, -1:fail)
	UINT8	address;		//g-sensor address
	UINT	bw_rate;		//baudrate
	UINT	power_control;	//power control
	UINT	data_format;	//data resolution (full resolution/ +-16g)
} SMBUSSETTING, *PSMBUSSETTING;


#ifdef __cplusplus    // If used by C++ code, 
extern "C" {          // we need to export the C interface
#endif

/*	Open the MxGeneralIo handle for later uses
	Inputs:
		none
	Returns:
		Result of MxGeneralIoOpen. Return 0 on failure.
*/
UINT32 mxsmbus_open();

/*
	set smbus state
	
	param:
		(in) smbus_base_addr : SMBUS address
		(in) psmbus_state : initial parameter to be set
			
	Return value:
		file descriptor : Success -1: fail
*/
int mxsmbus_set_state(UINT32 smbus_base_addr, PSMBUSSETTING psmbus_state);

/*
	clear GSensor offset
	
	param:
		(in) smbus_base_addr : smbus base address
		(in) psmbus_state : initial parameter to be set
			
	Return value:
		file descriptor : Success -1: fail
*/
int mxsmbus_clear_offset(UINT32 smbus_base_addr, PSMBUSSETTING psmbus_state);

/*
	Calibrate GSensor's offset
	
	param:
		(in) smbus_base_addr : SMBUS address
		(in) psmbus_state : initial parameter to be set
			
	Return value:
		file descriptor : Success -1: fail
*/
int mxsmbus_calibrate(UINT32 smbus_base_addr, PSMBUSSETTING psmbus_state);

/*
	get smbus state
	
	param:
		(in) smbus_base_addr
		(in) psmbus_state : initial parameter to be set
			
	Return value:
		file descriptor : Success -1: fail
*/
int mxsmbus_get_state(UINT32 smbus_base_addr, PSMBUSSETTING psmbus_state);

/*
	Read data from SMBUS
	
	param:
		(in) smbus_base_addr : 
		(in) psmbus_state : 
		(out) pgsensor_data :
		(out) sensor_data_length :
			
	Return value:
		file descriptor : Success -1: fail
*/
int mxsmbus_read(UINT32 smbus_base_addr, PSMBUSSETTING psmbus_state, PGSENSORDATA pgsensor_data, int sensor_data_length);

/*
	Write data to smbus
	
	param:
		(in) smbus_base_addr : 
		(in) address :
		(in) offset : 
		(in) length :
		(in) Data :
			
	Return value:
		status : Success 0 : fail : -1
*/
int mxsmbus_write(UINT32 smbus_base_addr, UINT8 address, UINT8 offset, UINT8 length, UINT8 *Data);

/*	close the SMBUS handle
	param:
		(in)smbus_base_addr :

	Returns:
		none
*/
void mxsmbus_close(UINT32 smbus_base_addr);

int SMBusReadByte (UINT32 smbus_base_addr, UINT8 Address, UINT8 Offset, UINT8 *Data);
int SMBusReadWord (UINT32 smbus_base_addr, UINT8 Address, UINT8 Offset, UINT8 *Data);
int SMBusReadBlockData (UINT32 smbus_base_addr, UINT8 Address, UINT8 Offset, UINT8 Length, UINT8 *Data);
int SMBusWriteByte (UINT32 smbus_base_addr, UINT8 Address, UINT8 Offset, UINT8 *Data);
int SMBusWriteWord(UINT32 smbus_base_addr, UINT8 Address, UINT8 Offset, UINT8 *Data);
int SMBusWriteBlockData (UINT32 smbus_base_addr, UINT8 Address, UINT8 Offset, UINT8 Length, UINT8 *Data);
int SMBusProcedureCall(UINT32 smbus_base_addr, UINT8 Address, UINT8 Offset, UINT8 *Data);


#ifdef __cplusplus    // If used by C++ code, 
}
#endif
#endif